<?php

/**
 * Class Emisms_WC_SMS_Admin
 */
class Emisms_WC_SMS_Admin {

	/**
	 * Emisms_WC_SMS_Admin constructor.
	 */
	public function __construct() {

		add_filter( 'woocommerce_settings_tabs_array', array( $this, 'add_settings_tab' ), 100 );

		add_action( 'woocommerce_settings_tabs_emisms_sms', array( $this, 'emisms_sms_settings_tab' ) );

		add_action( 'woocommerce_update_options_emisms_sms', array( $this, 'update_emisms_sms_settings' ) );

		add_action( 'woocommerce_admin_field_wc_emisms_sms_link', array( $this, 'add_link_field' ) );

		add_action( 'add_meta_boxes', array( $this, 'add_send_sms_meta_box' ) );

		add_action( 'wp_ajax_wc_emisms_sms_send_test_sms', array( $this, 'send_test_sms' ) );

		add_action( 'wp_ajax_wc_emisms_sms_send_order_sms', array( $this, 'send_order_sms' ) );

		add_action( 'admin_bar_menu', array( $this, 'show_emisms_sms_credits' ), 100 );

		add_filter( 'plugin_action_links_' . EMISMS_WC_SMS_BASENAME, array( $this, 'plugin_action_links' ) );
	}

	/**
	 * Add Emisms settings tab.
	 *
	 * @param array $settings_tabs.
	 *
	 * @return array
	 */
	public function add_settings_tab( $settings_tabs ) {

		$emisms_settings_tab = array();

		foreach ( $settings_tabs as $tab_id => $tab_title ) {

			$emisms_settings_tab[ $tab_id ] = $tab_title;

			if ( 'email' === $tab_id ) {
				$emisms_settings_tab['emisms_sms'] = 'EMISMS';
			}
		}

		return $emisms_settings_tab;
	}

	/**
	 * Emisms settings tab custom script.
	 */
	public function emisms_sms_settings_tab() {
		woocommerce_admin_fields( $this->get_emisms_sms_settings() );

		ob_start(); ?>
			jQuery( document ).ready( function(){
				if ( $('#wc_emisms_enable_admin_sms').is(':checked') == true ) {
					$( "#wc_emisms_admin_sms" ).closest( "tr" ).show();
					$( "#wc_emisms_admin_mobile" ).closest( "tr" ).show();
				}
				else{
					$( "#wc_emisms_admin_sms" ).closest( "tr" ).hide();
					$( "#wc_emisms_admin_mobile" ).closest( "tr" ).hide();
				}
				if ( $('#wc_emisms_order_pending').is(':checked') == true ) {
					$( "#wc_emisms_pending_sms" ).closest( "tr" ).show();
				}
				else{
					$( "#wc_emisms_pending_sms" ).closest( "tr" ).hide();
				}
				if ( $('#wc_emisms_order_on-hold').is(':checked') == true ) {
					$( "#wc_emisms_on-hold_sms" ).closest( "tr" ).show();
				}
				else{
					$( "#wc_emisms_on-hold_sms" ).closest( "tr" ).hide();
				}
				if ( $('#wc_emisms_order_processing').is(':checked') == true ) {
					$( "#wc_emisms_processing_sms" ).closest( "tr" ).show();
				}
				else{
					$( "#wc_emisms_processing_sms" ).closest( "tr" ).hide();
				}
				if ( $('#wc_emisms_order_completed').is(':checked') == true ) {
					$( "#wc_emisms_completed_sms" ).closest( "tr" ).show();
				}
				else{
					$( "#wc_emisms_completed_sms" ).closest( "tr" ).hide();
				}
				if ( $('#wc_emisms_order_cancelled').is(':checked') == true ) {
					$( "#wc_emisms_cancelled_sms" ).closest( "tr" ).show();
				}
				else{
					$( "#wc_emisms_cancelled_sms" ).closest( "tr" ).hide();
				}
				if ( $('#wc_emisms_order_refunded').is(':checked') == true ) {
					$( "#wc_emisms_refunded_sms" ).closest( "tr" ).show();
				}
				else{
					$( "#wc_emisms_refunded_sms" ).closest( "tr" ).hide();
				}
				if ( $('#wc_emisms_order_failed').is(':checked') == true ) {
					$( "#wc_emisms_failed_sms" ).closest( "tr" ).show();
				}
				else{
					$( "#wc_emisms_failed_sms" ).closest( "tr" ).hide();
				}

				$( '#wc_emisms_enable_admin_sms' ).change(function(){
					if( $(this).prop("checked") ) {
						$( "#wc_emisms_admin_sms" ).closest( "tr" ).show();
						$( "#wc_emisms_admin_mobile" ).closest( "tr" ).show();;
					} else {
						$( "#wc_emisms_admin_sms" ).closest( "tr" ).hide();
						$( "#wc_emisms_admin_mobile" ).closest( "tr" ).hide();
					}
				});
				$( '#wc_emisms_order_pending' ).change(function(){
					if( $(this).prop("checked") ) {
						$( "#wc_emisms_pending_sms" ).closest( "tr" ).show();
					} else {
						$( "#wc_emisms_pending_sms" ).closest( "tr" ).hide();
					}
				});
				$( '#wc_emisms_order_on-hold' ).change(function(){
					if( $(this).prop("checked") ) {
						$( "#wc_emisms_on-hold_sms" ).closest( "tr" ).show();
					} else {
						$( "#wc_emisms_on-hold_sms" ).closest( "tr" ).hide();
					}
				});
				$( '#wc_emisms_order_processing' ).change(function(){
					if( $(this).prop("checked") ) {
						$( "#wc_emisms_processing_sms" ).closest( "tr" ).show();
					} else {
						$( "#wc_emisms_processing_sms" ).closest( "tr" ).hide();
					}
				});
				$( '#wc_emisms_order_completed' ).change(function(){
					if( $(this).prop("checked") ) {
						$( "#wc_emisms_completed_sms" ).closest( "tr" ).show();
					} else {
						$( "#wc_emisms_completed_sms" ).closest( "tr" ).hide();
					}
				});
				$( '#wc_emisms_order_cancelled' ).change(function(){
					if( $(this).prop("checked") ) {
						$( "#wc_emisms_cancelled_sms" ).closest( "tr" ).show();
					} else {
						$( "#wc_emisms_cancelled_sms" ).closest( "tr" ).hide();
					}
				});
				$( '#wc_emisms_order_processing' ).change(function(){
					if( $(this).prop("checked") ) {
						$( "#wc_emisms_processing_sms" ).closest( "tr" ).show();
					} else {
						$( "#wc_emisms_processing_sms" ).closest( "tr" ).hide();
					}
				});
				$( '#wc_emisms_order_refunded' ).change(function(){
					if( $(this).prop("checked") ) {
						$( "#wc_emisms_refunded_sms" ).closest( "tr" ).show();
					} else {
						$( "#wc_emisms_refunded_sms" ).closest( "tr" ).hide();
					}
				});
				$( '#wc_emisms_order_failed' ).change(function(){
					if( $(this).prop("checked") ) {
						$( "#wc_emisms_failed_sms" ).closest( "tr" ).show();
					} else {
						$( "#wc_emisms_failed_sms" ).closest( "tr" ).hide();
					}
				});

				// handle SMS test send
				$('a.<?php echo 'wc_send_sms_test_sms_button'; ?>').on('click', function () {

					var number  = $('input#<?php echo 'wc_emisms_sms_test_mobile_number'; ?>');
					var message = $('textarea#<?php echo 'wc_emisms_sms_test_message'; ?>');

					// make sure values are not empty
					if ( ( !number.val() ) || ( !number.val() ) ) {
						alert("Please make sure you have entered a mobile phone number and test message.");
						return false;
					}

					// block UI
					number.closest('table').addClass( "processing" ).block( { message: null, overlayCSS: { background: "#fff", backgroundSize: "16px 16px", opacity: 0.6 } } );

					var data = {
						action			: 'wc_emisms_sms_send_test_sms',
						mobile_number	: number.val(),
						message			: message.val(),
						security		: '<?php echo wp_create_nonce( 'wc_emisms_sms_send_test_sms' ); ?>',

					};

					$.ajax(	{
						type:     "POST",
						url:      ajaxurl,
						data:     data,
						success:  function( response ) {

							if ( response ) {

								// unblock UI
								number.closest('table').unblock();

								// clear posted values
								number.val('');
								message.val('');

								// Display Success or Failure message from response
								alert(response);

							}
						},
						dataType: "html"
					} );

					return false;

				});

			});

		<?php
		wc_enqueue_js( ob_get_clean() );
	}

	/**
	 * Emisms WooCommerce settings.
	 *
	 * @return mixed|void
	 */
	public function get_emisms_sms_settings() {

		$settings = array(
			array(
				'title' => 'Emisms.com API Credentials',
				'type'  => 'title',
				'desc'  => 'Cette section vous permet de saisir vos informations d\'identification API Emisms. Pour obtenir vos identifiants API, connectez-vous à votre compte<a href="https://app.emisms.com" target="_blank">ICI</a> et cliquez sur le menu des paramètres. Si vous ne visitez pas votre compte<a href="https://emisms.com"  target="_blank">Emisms.com</a> pour vous inscrire et acheter des crédits SMS.',
			),
			array(
				'title' => 'Api Key',
				'desc'  => ' Entrez votre Emisms Api key',
				'type'  => 'text',
				'id'    => 'wc_emisms_api_key',
				'css'   => 'width:40%',
			),
			/*array(
				'title' => 'Access Token',
				'desc'  => 'Enter your Emisms Access token',
				'type'  => 'text',
				//'id'    => 'wc_emisms_api_token',
				'css'   => 'width:40%',
			),*/
			array(
				'title' => 'Sender ID',
				'desc'  => 'Saisissez l\'identifiant de l\'expéditeur du SMS. Maximum de onze (11) caractères. Numéros mobiles non autorisés',
				'type'  => 'text',
				'id'    => 'wc_emisms_sender_id',
			),

			array( 'type' => 'sectionend' ),

			array(
				'title' => 'Admin SMS Notifications',
				'type'  => 'title',
				'desc'  => 'Cette section vous permet d\'activer les notifications SMS à l\'administrateur pour les nouvelles commandes et de personnaliser le message SMS envoyé à l\'administrateur lorsqu\'une commande est passée.<br>Utilisez les balises ci-dessous pour personnaliser le message :
	            	<code>%first_name%</code>: Prénom du client
	            	<code>%last_name%</code>: Nom de famille du client
	            	<code>%phone_number%</code>: Numéro de téléphone du client
	            	<code>%shop_name%</code>:Nom de la boutique (' . get_bloginfo( 'name' ) . ')
	            	<code>%shop_url%</code>:  URL de la boutique(' . get_home_url() . ')
	            	<code>%order_id%</code>: Le numéro de commande
	            	<code>%order_amount%</code>: Le montant de la commande
	            	<code>%order_notes%</code>: Notes de commande fournies par le client
	            	<code>%products%</code>: Produits dans la commande. (Ex:Chaussure)
	            	<code>%products_with_quantity%</code>: Produits dans la commande avec la quantité commandée. (Ex: Chaussure (Qté : 10))
	            	<code>%payment_method%</code>: Mode de paiement utilisé pour régler la commande
	            	<code>%store_currency%</code>: La devise par défaut du magasin
	            	<code>%order_status%</code>: Le statut de la commande',
			),
			array(
				'id'       => 'wc_emisms_enable_admin_sms',
				'name'     => 'Activer la notification par SMS de nouvelle commande pour l\'administrateurs',
				'desc_tip' => 'Activer les notifications SMS de l\'administrateur sur les nouvelles commandes',
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'title' => 'Admin Mobile',
				'desc'  => '<br>Entrez le numéro de mobile auquel le SMS de nouvelle commande sera envoyé, au format 225070XXXXXXXX. Séparez plusieurs nombres par des virgules',
				'type'  => 'text',
				'id'    => 'wc_emisms_admin_mobile',
				'css'   => 'width:40%',
			),

			array(
				'id'       => 'wc_emisms_admin_sms',
				'name'     => 'Admin SMS Message',
				'desc_tip' => 'C\'est le message SMS qui est envoyé à l\'administrateur lorsqu\'une commande est passée',
				'css'      => 'min-width:500px;min-height:80px;',
				'default'  => 'Vous avez une nouvelle commande #%order_id% dans %shop_name% for %store_currency%%order_amount%',
				'type'     => 'textarea',
			),

			array( 'type' => 'sectionend' ),

			array(
				'title' => 'Customer SMS Notifications',
				'type'  => 'title',
				'desc'  => 'Cette section vous permet de sélectionner les changements de statut de commande qui enverront une notification SMS aux clients',
			),

			array(
				'name'          => 'Envoyer des notifications par SMS pour ces statuts de commande:',
				'id'            => 'wc_emisms_order_pending',
				'desc'          => 'En attente',
				'default'       => 'no',
				'type'          => 'checkbox',
				'checkboxgroup' => 'start',
			),

			array(
				'id'            => 'wc_emisms_order_on-hold',
				'desc'          => 'Mise en attente',
				'default'       => 'no',
				'type'          => 'checkbox',
				'checkboxgroup' => '',
			),

			array(
				'id'            => 'wc_emisms_order_processing',
				'desc'          => 'Traitement',
				'default'       => 'no',
				'type'          => 'checkbox',
				'checkboxgroup' => '',
			),

			array(
				'id'            => 'wc_emisms_order_completed',
				'desc'          => 'Terminé',
				'default'       => 'no',
				'type'          => 'checkbox',
				'checkboxgroup' => '',
			),

			array(
				'id'            => 'wc_emisms_order_cancelled',
				'desc'          => 'Annulé',
				'default'       => 'no',
				'type'          => 'checkbox',
				'checkboxgroup' => '',
			),

			array(
				'id'            => 'wc_emisms_order_refunded',
				'desc'          => 'Remboursé',
				'std'           => 'yes',
				'default'       => 'no',
				'type'          => 'checkbox',
				'checkboxgroup' => '',
			),

			array(
				'id'            => 'wc_emisms_order_failed',
				'desc'          => 'Échoué',
				'default'       => 'no',
				'type'          => 'checkbox',
				'checkboxgroup' => 'end',
			),

			array( 'type' => 'sectionend' ),

			array(
				'title' => 'Personnaliser les messages SMS',
				'type'  => 'title',
				'desc'  => 'Cette section vous permet de personnaliser le message SMS envoyé aux clients lorsque le statut de leur commande change.<br>Utilisez les balises ci-dessous pour personnaliser le message SMS:
	            	<code>%first_name%</code>: Prénom du client
	            	<code>%last_name%</code>:  Nom de famille du client
	            	<code>%phone_number%</code>: Numéro de mobile du client
	            	<code>%shop_name%</code>: Nom de la boutique (' . get_bloginfo( 'name' ) . ')
	            	<code>%shop_url%</code>: URL de la boutique (' . get_home_url() . ')
	            	<code>%order_id%</code>: Le numéro de commande
	            	<code>%order_amount%</code>: Le montant de la commande
	            	<code>%order_notes%</code>: Notes de commande fournies par le client
	            	<code>%products%</code>: Produits de la commande. (Ex:Chaussure)
	            	<code>%products_with_quantity%</code>: Produits dans l\'ordre avec la quantité commandée. (Ex: Chaussure (Qté : 10))
	            	<code>%payment_method%</code>: Mode de paiement utilisé pour régler la commande
	            	<code>%store_currency%</code>: La devise par défaut du magasin
	            	<code>%order_status%</code>: Status de la commande',
			),

			array(
				'id'       => 'wc_emisms_default_sms',
				'name'     => 'Message SMS client par défaut',
				'desc_tip' => 'This is the default SMS message that is sent when an order status changes.',
				'css'      => 'min-width:500px;min-height:80px;',
				'default'  => 'Bonjour %first_name% Merci d\'avoir passé une commande sur %shop_name%. Votre commande #%order_id% sur %shop_name% est maintenant %order_status%.',
				'type'     => 'textarea',
			),

			array(
				'id'       => 'wc_emisms_pending_sms',
				'name'     => 'En attente SMS Message',
				'desc_tip' => 'Saisissez un message SMS personnalisé à envoyer lorsque l\'état d\'une commande passe en attente ou laissez vide pour utiliser le message par défaut ci-dessus.',
				'css'      => 'min-width:500px;min-height:80px;',
				'type'     => 'textarea',
			),

			array(
				'id'       => 'wc_emisms_on-hold_sms',
				'name'     => 'Mise en attente SMS Message',
				'desc_tip' => 'Saisissez un message SMS personnalisé à envoyer lorsque l\'état d\'une commande passe en attente ou laissez un blanc pour utiliser le message par défaut ci-dessus.',
				'css'      => 'min-width:500px;min-height:80px;',
				'type'     => 'textarea',
			),

			array(
				'id'       => 'wc_emisms_processing_sms',
				'name'     => 'Traitement SMS Message',
				'desc_tip' => 'Enter a custom SMS message to be sent when an order status is changed to processing or leave blank to use the default message above.',
				'css'      => 'min-width:500px;min-height:80px;',
				'type'     => 'textarea',
			),

			array(
				'id'       => 'wc_emisms_completed_sms',
				'name'     => 'Terminé SMS Message',
				'desc_tip' => 'Saisissez un message SMS personnalisé à envoyer pour les commandes terminées ou laissez le champ vide pour utiliser le message par défaut ci-dessus.',
				'css'      => 'min-width:500px;min-height:80px;',
				'type'     => 'textarea',
			),

			array(
				'id'       => 'wc_emisms_cancelled_sms',
				'name'     => 'Annulé SMS Message',
				'desc_tip' => 'Entrez un message SMS personnalisé à envoyer lorsqu\'un statut de commande est modifié en annulé ou laissez vide pour utiliser le message par défaut ci-dessus.',
				'css'      => 'min-width:500px;min-height:80px;',
				'type'     => 'textarea',
			),

			array(
				'id'       => 'wc_emisms_refunded_sms',
				'name'     => ' Remboursé SMS Message',
				'desc_tip' => 'Saisissez un message SMS personnalisé à envoyer lorsque le statut d\'une commande est modifié en remboursement ou laissez vide pour utiliser le message par défaut ci-dessus.',
				'css'      => 'min-width:500px;min-height:80px;',
				'type'     => 'textarea',
			),

			array(
				'id'       => 'wc_emisms_failed_sms',
				'name'     => 'Echoué SMS Message',
				'desc_tip' => 'Saisissez un message SMS personnalisé à envoyer lorsque l\'état d\'une commande est modifié en échec ou laissez vide pour utiliser le message par défaut ci-dessus.',
				'css'      => 'min-width:500px;min-height:80px;',
				'type'     => 'textarea',
			),

			array( 'type' => 'sectionend' ),

			array(
				'name' => 'Envoyer un SMS d\'essai',
				'type' => 'title',
				'desc' => 'L\'ID d\'expéditeur qui sera utilisé est celui qui a été défini ci-dessus.',
			),

			array(
				'id'       => 'wc_emisms_sms_test_mobile_number',
				'name'     => 'Mobile Number',
				'desc_tip' => 'Saisissez le numéro de téléphone mobile auquel le SMS sera envoyé.',
				'type'     => 'text',
			),

			array(
				'id'       => 'wc_emisms_sms_test_message',
				'name'     => 'Message',
				'desc_tip' => 'Saisissez le message de test à envoyer.',
				'type'     => 'textarea',
				'css'      => 'min-width: 500px;',
			),

			array(
				'name'   => 'Send SMS',
				'href'   => '#',
				'class'  => 'wc_send_sms_test_sms_button button',
				'length' => 160,
				'type'   => 'wc_emisms_sms_link',
			),

			array( 'type' => 'sectionend' ),

		);

		return apply_filters( 'emisms_api_details_settings', $settings );
	}

	/**
	 * Add link field.
	 *
	 * @param $field
	 */
	public function add_link_field( $field ) {

		if ( isset( $field['name'] ) && isset( $field['class'] ) && isset( $field['href'] ) ) :

			?>
			<tr valign="top">
				<th scope="row" class="titledesc"></th>
				<td class="forminp">
					<a href="<?php echo esc_url( $field['href'] ); ?>" class="<?php echo esc_attr( $field['class'] ); ?>"><?php echo wp_filter_kses( $field['name'] ); ?></a>
				</td>
			</tr>
			<?php

		endif;
	}

	/**
	 * Save Emisms settings.
	 */
	public function update_emisms_sms_settings() {
		woocommerce_update_options( $this->get_emisms_sms_settings() );
	}

	/**
	 * Add send message metabox.
	 */
	public function add_send_sms_meta_box() {

		add_meta_box(
			'wc_emisms_send_sms_meta_box',
			'Emisms: Send SMS To Customer',
			array( $this, 'display_send_sms_meta_box' ),
			'shop_order',
			'side',
			'default'
		);
	}

	/**
	 * Display send message metabox.
	 *
	 * @param WP_Post $post WP_Post.
	 */
	public function display_send_sms_meta_box( $post ) {

		global $post;
		?>
		<p><textarea type="text" name="wc_emisms_sms_order_message" id="wc_emisms_sms_order_message" class="input-text" style="width: 100%;" rows="4"></textarea></p>
		<p><a class="button tips" id="wc_emisms_sms_order_send_message" data-tip="Send an SMS to the billing phone number for this order.">Send SMS</a>
		<span id="wc_emisms_sms_order_message_char_count" style="color: green; float: right; font-size: 16px;">0</span></p>

		<?php ob_start(); ?>
			// character count
			$('#wc_emisms_sms_order_message').on('change keyup input', function() {

				$('#wc_emisms_sms_order_message_char_count').text( $(this).val().length );

				if( $(this).val().length > 160 ) {
					$('#wc_emisms_sms_order_message_char_count').css('color','red');
				}
			});

			// AJAX message send
			$( "a#wc_emisms_sms_order_send_message" ).click( function( e ) {

				var $section = $( "div#wc_emisms_send_sms_meta_box" ),
					$message = $( "textarea#wc_emisms_sms_order_message" );

				if ( $section.is( ".processing" ) ) return false;

				$section.addClass( "processing" ).block( { message: null, overlayCSS: { background: "#fff", backgroundSize: "16px 16px", opacity: 0.6 } } );

				var data = {
					action:    "wc_emisms_sms_send_order_sms",
					security:  "<?php echo wp_create_nonce( 'wc_emisms_sms_send_order_sms' ); ?>",
					order_id:  "<?php echo esc_js( $post->ID ); ?>",
					message:   $message.val()
				};

				$.ajax(	{
					type:     "POST",
					url:      ajaxurl,
					data:     data,
					success:  function( response ) {

						$section.removeClass( "processing" ).unblock();

						if ( response ) {
							$section.block( { message: response, timeout: 2000 } );
							$message.val( '' );
						}
					},
					dataType: "html"
				} );
				return false;
			});
		<?php

		wc_enqueue_js( ob_get_clean() );
	}

	/**
	 * Send test message
	 */
	public function send_test_sms() {

		if ( ! is_admin() || ! current_user_can( 'edit_posts' ) ) {
			wp_die( 'Vous ne disposez pas des autorisations suffisantes pour accéder à cette page.' );
		}

		if ( ! wp_verify_nonce( $_POST['security'], 'wc_emisms_sms_send_test_sms' ) ) {
			wp_die( 'Vous avez mis trop de temps, veuillez revenir en arrière et réessayer' );
		}

		$message = sanitize_textarea_field( $_POST['message'] );
		$phone   = sanitize_text_field( $_POST['mobile_number'] );

		$emisms_wc_sms = new Emisms_WC_SMS();

		$send_sms = $emisms_wc_sms->send_sms( $phone, $message );

		if ( isset( $send_sms->{'code'} ) && ( 'ok' == $send_sms->{'code'} ) ) {
			exit( 'Message Envoyé avec succès' );
		} else {
			exit( 'Message Not Sent '   );
		}
	}

	/**
	 * Send message from the order details page.
	 */
	public function send_order_sms() {

		if ( ! is_admin() || ! current_user_can( 'edit_posts' ) ) {
			wp_die( 'Vous ne disposez pas des autorisations suffisantes pour accéder à cette page.' );
		}

		if ( ! wp_verify_nonce( $_POST['security'], 'wc_emisms_sms_send_order_sms' ) ) {
			wp_die( 'Vous avez mis trop de temps, veuillez revenir en arrière et réessayer.' );
		}

		$message = sanitize_textarea_field( $_POST['message'] );

		$order_id = ( is_numeric( $_POST['order_id'] ) ) ? absint( $_POST['order_id'] ) : null;

		if ( ! $order_id ) {
			return;
		}

		$order = wc_get_order( $order_id );

		$phone = method_exists( $order, 'get_billing_phone' ) ? $order->get_billing_phone() : $order->billing_phone;

		$emisms_wc_sms = new Emisms_WC_SMS();

		$message = $emisms_wc_sms->replace_message_variables( $message, $order_id );

		$send_sms = $emisms_wc_sms->send_sms( $phone, $message, true, $order_id );


		if( isset( $send_sms->{'code'} ) && ( 'ok' == $send_sms->{'code'} ) ) {
			exit( 'Message Envoyé avec succès' );
		} else {
			exit( 'Message Not Sent ' );
		}
	}

	/**
	 * Display Emisms credits balance in the admin bar.
	 *
	 * @param $wp_admin_bar
	 */
	public function show_emisms_sms_credits( $wp_admin_bar ) {

		if ( ! is_admin_bar_showing() || ! current_user_can( 'manage_woocommerce' ) ) {
			return;
		}

		if ( false === ( $my_query = get_transient( 'emisms_available_sms_credits' ) ) ) {

			$api_key   = get_option( 'wc_emisms_api_key', true );
			//$api_token = get_option( 'wc_emisms_api_token', true );

			if ( empty( $api_key )) {
				return;
			}

			/*$headers = array(
				'Authorization' => 'Basic ' . base64_encode( $api_key . ':' . $api_token ),
			);*/

			$args = array(
				//'headers' => $headers,
				'timeout' => 60,
			);

			$url = 'https://app.emisms.com/sms/api?action=check-balance';

			$response = wp_remote_get( $url, $args );

			if ( ! is_wp_error( $response ) && 200 === (int) wp_remote_retrieve_response_code( $response ) ) {
				$body = json_decode( wp_remote_retrieve_body( $response ) );
				set_transient( 'emisms_available_sms_credits', $body->sms_credits, 12 * HOUR_IN_SECONDS );
			}
		}

		$sms_credits = get_transient( 'emisms_available_sms_credits' );

		if ( $sms_credits ) {

			$message = 'You have ' . $sms_credits . ' SMS credits left';

			$menu_args = array(
				'id'    => 'wc_emisms_sms_admin_bar_menu',
				'title' => 'EMISMS Credits: ' . $sms_credits,
				'href'  => false,
			);

			$sms_usage_item_args = array(
				'id'     => 'wc_emisms_sms_sms_usage_item',
				'title'  => $message,
				'href'   => false,
				'parent' => 'wc_emisms_sms_admin_bar_menu',
			);

			$add_funds_item_args = array(
				'id'     => 'wc_emisms_sms_add_funds_item',
				'title'  => 'Buy SMS Credits for Your Emisms Account',
				'href'   => 'https://app.emisms.com/user/sms/buy-unit',
				'meta'   => array( 'target' => '_blank' ),
				'parent' => 'wc_emisms_sms_admin_bar_menu',
			);

			$wp_admin_bar->add_menu( $menu_args );
			$wp_admin_bar->add_menu( $sms_usage_item_args );
			$wp_admin_bar->add_menu( $add_funds_item_args );
		}
	}

	/**
	 * Plugin action links.
	 *
	 * @param array $links Action links.
	 *
	 * @return array
	 */
	public function plugin_action_links( $links ) {
		$settings_link = array(
			'settings' => '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=emisms_sms' ) . '" title="View Emisms Settings">Settings</a>',
		);
		return array_merge( $links, $settings_link );
	}

}
new Emisms_WC_SMS_Admin();

